ctypes.c_int.__ctype_be__

ctypes :: c_int :: __ctype_be__ :: Class __ctype_be__ |
[frames] | no frames]

# Class __ctype_be__

          object --+
                   |
           ??._CData --+
                       |
    _ctypes._SimpleCData --+
                           |
                          c_int.__ctype_be__

Nested Classes
| __ctype_be__
| __ctype_le__

Instance Methods
Inherited from `_ctypes._SimpleCData`: `__ctypes_from_outparam__`, `__init__`, `__new__`, `__nonzero__`, `__repr__` Inherited from `_CData`: `__hash__`, `__reduce__`, `__setstate__` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties
Inherited from `_ctypes._SimpleCData`: `value` Inherited from `object`: `__class__`